========================
STELAR Client User Guide
========================


The STELAR Client is a Python client that provides a programmatic interface to the STELAR Knowledge Layer 
Management System (KLMS). The client allows users to interact with the KLMS, including creating and updating entities, 
executing tasks and workflows, managing tools, and accessing the STELAR API.

In order to fully utilize the STELAR Client, users should be familiar with the concepts and terminology used in the STELAR KLMS.
This document provides an overview of the STELAR KLMS and describes how to use the STELAR Client to interact with the KLMS.


.. include:: ../docs/stelaroverview.rst
.. include:: ../docs/datacatalog.rst

..
  .. include:: ../docs/minio.rst
  .. include:: ../docs/tasks.rst
  .. include:: ../docs/tools.rst
  .. include:: ../docs/api.rst
  .. include:: ../docs/usermanagement.rst
  .. include:: ../docs/authorization.rst
  .. include:: ../docs/knowledgegraph.rst





**********************************
Working with data in Storage
**********************************


Contents:
    - An overview of the STELAR KLMS
    - Working with the Data Catalog
      - Overview of the Data Catalog
      - Creating entities
      - Updating entities
      - Custom fields
      - Tags
      - Searching for entities
    - Working with data in minio
    - Execution of tasks and workflows
    - Managing tools
    - Accessing the STELAR API
    - User management
    - Authorization policies
    - Using the Knowledge Graph
  
